#!/usr/bin/env python

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------
import os
import re

from setuptools import setup, find_packages

# Version extraction inspired from 'requests'
with open(os.path.join('coregen', '_version.py'), 'r') as fd:
    version = re.search(r'^VERSION\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('Cannot find version information')

setup(
    name="coregen",
    version=version,
    description='Microsoft Generator Plugins for Python',
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',
    license='MIT License',
    author='Microsoft Corporation',
    author_email='azpysdkhelp@microsoft.com',
    url='https://github.com/Azure/autorest.python',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'License :: OSI Approved :: MIT License',
    ],
    packages=find_packages(exclude=[
        'test',
    ]),
    install_requires=[
        "json-rpc",
        "Jinja2 >= 2.11", # I need "include" and auto-context + blank line are not indented by default
        "pyyaml",
        "m2r2",
        "black",
        "docutils<0.19", # m2r2 fails with docutils 0.19
    ],
)
